Version 0.23 (25, May, 2014)

- Support following options in kakasi command.
 + same as original kakasi
  -J{aKH} -K{aH} -H{aK} -E{a}
  -rk -rh
  -w -s -S -C
 + additional options
  -v --version -h --help
  -O --output: output file
  -I --input: input file
- Change default behavior as almost same
  as original kakasi
- Zenkaku numbers conversion
- Passport roman conversion table

Version 0.22 (3, May, 2014)

- Introduced kakasi command
- Symbols support

Version 0.21 (27, April, 2014)

- Wakati conversion support

Version 0.20 (27, April, 2014)

- Pickled roman tables

Version 0.10 (25, April, 2014)

- Work on python 2.6, 2.7, 3.3, 3.4
  (Thanks @FGtatsuro)
- Kunrei and Hepburn roman table
